@@ -104,6 +104,9 @@ def progressbar_module():
     return progressbar_mod
 
 
+g_setup_logging_args = 'pyrocko', 'warning'
+
+
 def setup_logging(programname='pyrocko', levelname='warning'):
     '''
     Initialize logging.
@@ -117,6 +120,9 @@ def setup_logging(programname='pyrocko', levelname='warning'):
     :py:func:`logging.basicConfig()`.
     '''
 
+    global g_setup_logging_args
+    g_setup_logging_args = (programname, levelname)
+
     levels = {'debug': logging.DEBUG,
               'info': logging.INFO,
               'warning': logging.WARNING,
@@ -128,6 +134,16 @@ def setup_logging(programname='pyrocko', levelname='warning'):
         format=programname+':%(name)-20s - %(levelname)-8s - %(message)s')
 
 
+def subprocess_setup_logging_args():
+    '''
+    Get arguments from previous call to setup_logging.
+
+    These can be sent down to a worker process so it can setup its logging
+    in the same way as the main process.
+    '''
+    return g_setup_logging_args
+
+
 def data_file(fn):
     return os.path.join(os.path.split(__file__)[0], 'data', fn)
 
@@ -630,6 +646,158 @@ def plf_integrate_piecewise(x_edges, x, y):
     return num.diff(y_all[-len(y_edges):])
 
 
+def diff_fd_1d_4o(dt, data):
+    '''
+    Approximate first derivative of an array (forth order, central FD).
+
+    :param dt: sampling interval
+    :param data: NumPy array with data samples
+
+    :returns: NumPy array with same shape as input
+
+    Interior points are approximated to fourth order, edge points to first
+    order right- or left-sided respectively, points next to edge to second
+    order central.
+    '''
+    import scipy.signal
+
+    ddata = num.empty_like(data, dtype=num.float)
+
+    if data.size >= 5:
+        ddata[2:-2] = scipy.signal.lfilter(
+            [-1., +8., 0., -8., 1.], [1.], data)[4:] / (12.*dt)
+
+    if data.size >= 3:
+        ddata[1] = (data[2] - data[0]) / (2. * dt)
+        ddata[-2] = (data[-1] - data[-3]) / (2. * dt)
+
+    if data.size >= 2:
+        ddata[0] = (data[1] - data[0]) / dt
+        ddata[-1] = (data[-1] - data[-2]) / dt
+
+    if data.size == 1:
+        ddata[0] = 0.0
+
+    return ddata
+
+
+def diff_fd_1d_2o(dt, data):
+    '''
+    Approximate first derivative of an array (second order, central FD).
+
+    :param dt: sampling interval
+    :param data: NumPy array with data samples
+
+    :returns: NumPy array with same shape as input
+
+    Interior points are approximated to second order, edge points to first
+    order right- or left-sided respectively.
+
+    Uses :py:func:`numpy.gradient`.
+    '''
+
+    return num.gradient(data, dt)
+
+
+def diff_fd_2d_4o(dt, data):
+    '''
+    Approximate second derivative of an array (forth order, central FD).
+
+    :param dt: sampling interval
+    :param data: NumPy array with data samples
+
+    :returns: NumPy array with same shape as input
+
+    Interior points are approximated to fourth order, next-to-edge points to
+    second order, edge points repeated.
+    '''
+    import scipy.signal
+
+    ddata = num.empty_like(data, dtype=num.float)
+
+    if data.size >= 5:
+        ddata[2:-2] = scipy.signal.lfilter(
+            [-1., +16., -30., +16., -1.], [1.], data)[4:] / (12.*dt**2)
+
+    if data.size >= 3:
+        ddata[:2] = (data[2] - 2.0 * data[1] + data[0]) / dt**2
+        ddata[-2:] = (data[-1] - 2.0 * data[-2] + data[-3]) / dt**2
+
+    if data.size < 3:
+        ddata[:] = 0.0
+
+    return ddata
+
+
+def diff_fd_2d_2o(dt, data):
+    '''
+    Approximate second derivative of an array (second order, central FD).
+
+    :param dt: sampling interval
+    :param data: NumPy array with data samples
+
+    :returns: NumPy array with same shape as input
+
+    Interior points are approximated to second order, edge points repeated.
+    '''
+    import scipy.signal
+
+    ddata = num.empty_like(data, dtype=num.float)
+
+    if data.size >= 3:
+        ddata[1:-1] = scipy.signal.lfilter(
+            [1., -2., 1.], [1.], data)[2:] / (dt**2)
+
+        ddata[0] = ddata[1]
+        ddata[-1] = ddata[-2]
+
+    if data.size < 3:
+        ddata[:] = 0.0
+
+    return ddata
+
+
+def diff_fd(n, order, dt, data):
+    '''
+    Approximate 1st or 2nd derivative of an array.
+
+    :param n: 1 for first derivative, 2 for second
+    :param order: order of the approximation 2 and 4 are supported
+    :param dt: sampling interval
+    :param data: NumPy array with data samples
+
+    :returns: NumPy array with same shape as input
+
+    This is a frontend to the functions :py:func:`diff_fd_1d_2o`,
+    :py:func:`diff_fd_1d_4o`, :py:func:`diff_fd_2d_2o`, and
+    :py:func:`diff_fd_2d_4o`.
+
+    Raises :py:exc:`ValueError` for unsupported `n` or `order`.
+    '''
+
+    funcs = {
+        1: {2: diff_fd_1d_2o, 4: diff_fd_1d_4o},
+        2: {2: diff_fd_2d_2o, 4: diff_fd_2d_4o}}
+
+    try:
+        funcs_n = funcs[n]
+    except KeyError:
+        raise ValueError(
+            'pyrocko.util.diff_fd: '
+            'Only 1st and 2sd derivatives are supported.')
+
+    try:
+        func = funcs_n[order]
+    except KeyError:
+        raise ValueError(
+            'pyrocko.util.diff_fd: '
+            'Order %i is not supported for %s derivative. Supported: %s' % (
+                order, ['', '1st', '2nd'][n],
+                ', '.join('%i' % order for order in sorted(funcs_n.keys()))))
+
+    return func(dt, data)
+
+
 class GlobalVars(object):
     reuse_store = dict()
     decitab_nmax = 0
@@ -740,14 +908,14 @@ def mk_decitab(nmax=100):
     for i in range(1, 10):
         for j in range(1, i+1):
             for k in range(1, j+1):
-                for l in range(1, k+1):
-                    for m in range(1, l+1):
-                        p = i*j*k*l*m
+                for l_ in range(1, k+1):
+                    for m in range(1, l_+1):
+                        p = i*j*k*l_*m
                         if p > nmax:
                             break
                         if p not in tab:
-                            tab[p] = (i, j, k, l, m)
-                    if i*j*k*l > nmax:
+                            tab[p] = (i, j, k, l_, m)
+                    if i*j*k*l_ > nmax:
                         break
                 if i*j*k > nmax:
                     break
@@ -763,6 +931,81 @@ def zfmt(n):
     return '%%0%ii' % (int(math.log10(n - 1)) + 1)
 
 
+def _year_to_time(year):
+    tt = (year, 1, 1, 0, 0, 0)
+    return calendar.timegm(tt)
+
+
+def _working_year(year):
+    try:
+        tt = (year, 1, 1, 0, 0, 0)
+        t = calendar.timegm(tt)
+        tt2_ = time.gmtime(t)
+        tt2 = tuple(tt2_)[:6]
+        if tt != tt2:
+            return False
+
+        s = '%i-01-01 00:00:00' % year
+        s2 = time.strftime('%Y-%m-%d %H:%M:%S', tt2_)
+        if s != s2:
+            return False
+
+    except Exception:
+        return False
+
+    return True
+
+
+g_working_system_time_range = None
+
+
+def get_working_system_time_range():
+    '''
+    Check time range supported by the systems's time conversion functions.
+
+    Returns system time stamps of start of year of first/last fully supported
+    year span. If this is before 1900 or after 2100, return first/last century
+    which is fully supported.
+
+    :returns: ``(tmin, tmax, year_min, year_max)``
+    '''
+
+    global g_working_system_time_range
+
+    if g_working_system_time_range is None:
+        year0 = 2000
+        year_min = year0
+        year_max = year0
+
+        itests = list(range(101))
+        for i in range(19):
+            itests.append(200 + i*100)
+
+        for i in itests:
+            if not _working_year(year0 - i):
+                break
+            else:
+                year_min = year0 - i
+
+        for i in itests:
+            if not _working_year(year0 + i + 1):
+                break
+            else:
+                year_max = year0 + i
+
+        g_working_system_time_range = (
+            _year_to_time(year_min),
+            _year_to_time(year_max),
+            year_min, year_max)
+
+    return g_working_system_time_range
+
+
+def is_working_time(t):
+    tmin, tmax, _, _ = get_working_system_time_range()
+    return tmin <= t <= tmax
+
+
 def julian_day_of_year(timestamp):
     '''
     Get the day number after the 1st of January of year in ``timestamp``.
